@@ -23,7 +23,7 @@
 
 #include "gsm-session-fill.h"
 
-#include "gsm-consolekit.h"
+#include "gsm-system.h"
 #include "gsm-manager.h"
 #include "gsm-process-helper.h"
 #include "gsm-util.h"
@@ -181,18 +181,17 @@ check_required (GKeyFile *keyfile)
 static void
 maybe_load_saved_session_apps (GsmManager *manager)
 {
-        GsmConsolekit *consolekit;
-        char *session_type;
+        GsmSystem *system;
+        gboolean is_login;
 
-        consolekit = gsm_get_consolekit ();
-        session_type = gsm_consolekit_get_current_session_type (consolekit);
+        system = gsm_get_system ();
+        is_login = gsm_system_is_login_session (system);
+        g_object_unref (system);
 
-        if (g_strcmp0 (session_type, GSM_CONSOLEKIT_SESSION_TYPE_LOGIN_WINDOW) != 0) {
-                gsm_manager_add_autostart_apps_from_dir (manager, gsm_util_get_saved_session_dir ());
-        }
+        if (is_login)
+                return;
 
-        g_object_unref (consolekit);
-        g_free (session_type);
+        gsm_manager_add_autostart_apps_from_dir (manager, gsm_util_get_saved_session_dir ());
 }
 
 static void
