@@ -81,6 +81,18 @@ gsm_system_can_restart (GsmSystem *system)
         return GSM_SYSTEM_GET_IFACE (system)->can_restart (system);
 }
 
+gboolean
+gsm_system_can_suspend (GsmSystem *system)
+{
+        return GSM_SYSTEM_GET_IFACE (system)->can_suspend (system);
+}
+
+gboolean
+gsm_system_can_hibernate (GsmSystem *system)
+{
+        return GSM_SYSTEM_GET_IFACE (system)->can_hibernate (system);
+}
+
 void
 gsm_system_attempt_stop (GsmSystem *system)
 {
@@ -93,6 +105,18 @@ gsm_system_attempt_restart (GsmSystem *system)
         GSM_SYSTEM_GET_IFACE (system)->attempt_restart (system);
 }
 
+void
+gsm_system_suspend (GsmSystem *system)
+{
+        GSM_SYSTEM_GET_IFACE (system)->suspend (system);
+}
+
+void
+gsm_system_hibernate (GsmSystem *system)
+{
+        GSM_SYSTEM_GET_IFACE (system)->hibernate (system);
+}
+
 void
 gsm_system_set_session_idle (GsmSystem *system,
                              gboolean   is_idle)
@@ -100,6 +124,21 @@ gsm_system_set_session_idle (GsmSystem *system,
         GSM_SYSTEM_GET_IFACE (system)->set_session_idle (system, is_idle);
 }
 
+void
+gsm_system_add_inhibitor (GsmSystem        *system,
+                          const gchar      *id,
+                          GsmInhibitorFlag  flag)
+{
+        GSM_SYSTEM_GET_IFACE (system)->add_inhibitor (system, id, flag);
+}
+
+void
+gsm_system_remove_inhibitor (GsmSystem   *system,
+                             const gchar *id)
+{
+        GSM_SYSTEM_GET_IFACE (system)->remove_inhibitor (system, id);
+}
+
 gboolean
 gsm_system_is_login_session (GsmSystem *system)
 {
